<?php
// Removed CS5100, PM5315 added P308
//bobg 21may08 29mar12
	$page_id = "013";
	include "assist/.access.php";
	include "assist/tzone.php"; // include timezone
    $script=basename($_SERVER['SCRIPT_NAME']);
if (isset($_POST['checkbox'])) {
   $from=$_POST['from'];
   $to=$_POST['to'];
   } else $from = $to = -1;
if (isset($_POST['submit'])) {
    $submit=1;
   $from=$_POST['from'];
   $statusfm=$_POST['statusfm'];
   $statusto=$_POST['statusto'];
   $to=$_POST['to'];
   $ipp=$_POST['ipp'];
   $potsp=$_POST['potsp'];
print "from=$from, statusfm=$statusfm, to=$to, statusto=$statusto, ipp=$ipp, potsp=$potsp<br/>";
   } else $submit=0;
$fs = (filesize("/SpliceCom/Database.txt"));
$pause = ceil(($fs/(1024 * 1024)))*1000;
?>
<html>
<head>
<title>Move Phones/PCS - Between Modules. Fix POTS</title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
<link rel="shortcut icon" href="favicon.ico">
<link rel="stylesheet" type="text/css" href="css/Styles.css" media="screen" />
<script src="assist/js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<script src="assist/js/wiz/main.js" type="text/javascript"></script>
<script type="text/javascript">
$(document).ready(function(){
	 $("#tbl").sticky();
 });

var pause = <?php echo $pause; ?>;
$(function() {
	$(window).scroll(function() {
		if($(this).scrollTop() != 0) {
			$('#toTop').fadeIn();
		} else {
			$('#toTop').fadeOut();
		}
	});
	$('#toTop').click(function() {
		$('body,html').animate({scrollTop:0},800);
	});
	$("#backup").click(function () { $.ajax({ url : 'dobackup.php' }); $('#loader').show().delay(pause).hide(0); $('#done').hide().delay(pause).show(0); });
});
</script>
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body>
<div id="toTop">^ Back to Top</div>
<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo $script?>'" src="assist/images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('assist/help/help_movephones.php','help','600','500','yes');return false" src="assist/images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist/assist.php'" src="assist/images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="assist/images/home16.gif" alt="home" title="home" border="0">
</div>
<div style="position:absolute; top:30px; right:10px" >
<a href="<?php echo $script?>?add=1" alt="Add Temp Modules" title="Add Temp Modules">Add Temp Modules</a>&nbsp;|&nbsp;
<a href="<?php echo $script?>?delete=1" alt="Delete Temp Modules" title="Delete Temp Modules">Delete Temp Modules</a>&nbsp;|&nbsp;
<a href="<?php echo $script?>?fix=1" alt="Fix POTS Ports" title="Fix POTS Ports">Fix POTS Ports</a>
</div><br/>
<div style="position:absolute; top:50px; right:10px" >
<a href="#" id="backup" alt="Create System Backup" title="Create System Backup">Create System Backup</a>
<div id='loader' style='display: none;'><br/><img src='assist/images/loader.gif'/></div>
<div id="done" style="display: none;"><br/>Backup Created</div>
</div>
<div id="contain">
<h2><img src='assist/images/settings.png' style="vertical-align:middle;">&nbsp;Move Phones/PCS - Between Modules. Fix POTS</h2>
<?php
$ds = @ldap_connect("127.0.0.1",4000) or exit("<p>EXIT: LDAP connect failure</p>");
@ldap_bind($ds,"INTERNAL","0123456") or exit("<p>EXIT: LDAP bind failure</p>");
// move phones has been clicked.
if ($submit){
   print "Moving phones from: $from, to: $to<br/>";
   $dn="cn=$to,cn=Modules";
   $sr=ldap_read($ds,$dn,'objectclass=Module');
   $info=ldap_get_entries($ds,$sr);
   print $info[0]['guid'][0]." = to locn<br/>";
   $to_locn=$info[0]['guid'][0];
   // on out temp phone modules we add to the next free port so build an array of them
   unset($ports);
   $ports=array();
   for ($n=1;$n<=$potsp;$n++) {
      $ports[$n]=sprintf("port%02d",$n);
   }
   if(strpos($to,"czc temp 43")==1) {
      $sr=ldap_list($ds,$dn,"objectclass=Phone");
      $info=ldap_get_entries($ds,$sr);
      for ($n=0;$n<$info['count'];$n++) {
         if ($port=array_search($info[$n]['cn'][0],$ports)) unset($ports[$port]);
      }
   }
    $dn="cn=$from,cn=Modules";
    $sr=ldap_read($ds,$dn,'objectclass=Module');
    $info=ldap_get_entries($ds,$sr);
    print $info[0]['guid'][0]." = from locn<br/>";
    $from_locn=$info[0]['guid'][0];
    $sr=ldap_list($ds,$dn,'objectclass=Phone');
    $info=ldap_get_entries($ds,$sr);
    $phone1=0; //number of pots phones so far
    for ($n=0;$n<$info['count'];$n++) {
        $phonetype=$move=0;
        print"n=$n, type=".$info[$n]['typeofphone'][0].", ".$info[$n]['cn'][0]."<br/>";
        if ($info[$n]['typeofphone'][0]==1 or $info[$n]['typeofphone'][0]==2 or $info[$n]['typeofphone'][0]==3){
            $att=array();
            $from_dn=$info[$n]['dn'];
            $from_phone=$info[$n]['guid'][0];
			print $from_dn.", ";
            $att['cn']=$info[$n]['cn'][0];
            $att['description']=$info[$n]['description'][0];
            $att['location']=$to_locn;
            $att['owner']=$info[$n]['owner'][0];
            $att['productversion']=$info[$n]['productversion'][0];
            $att['typeofphone']=$info[$n]['typeofphone'][0];
            $att['objectclass']=$info[$n]['objectclass'][0];
            $dn="cn=1,".$info[$n]['dn'];
            $sr1=ldap_read($ds,$dn,'objectclass=*');
            $info1=ldap_get_entries($ds,$sr1);
            $att1=array();
            $att1['objectclass']=$info1[0]['objectclass'][0];
            $att1['cn']=$info1[0]['cn'][0];
            if ($info[$n]['typeofphone'][0]==1) {
               $phonetype=1;
               //get next free port
               if($a=each($ports)) {
                  $att['cn']=$a[1];
                  $move=1;
               }
               else $move=0;
               unset($att['location']);
               $att1['callerdisplaylen']=$info1[0]['callerdisplaylen'][0];
               $att1['callerdisplaytype']=$info1[0]['callerdisplaytype'][0];
               $att1['offhookworking']=$info1[0]['offhookworking'][0];
               $att1['pagingport']=$info1[0]['pagingport'][0];
               $att1['partnerlogincode']=$info1[0]['partnerlogincode'][0];
               $att1['regeneratedtmf']=$info1[0]['regeneratedtmf'][0];
               $att1['remoteidle']=$info1[0]['remoteidle'][0];
               $att1['remotepstn']=$info1[0]['remotepstn'][0];
               $att1['unlicensed']=$info1[0]['unlicensed'][0];
            }
            elseif ($info[$n]['typeofphone'][0]==2) {
                $phonetype=2;
                $move=$ipp;
                $att1['compressiontype']=$info1[0]['compressiontype'][0];
                $att1['model']=$info1[0]['model'][0];
                $att1['javalicense']=$info1[0]['javalicense'][0];
                $att1['partnerlogincode']=$info1[0]['partnerlogincode'][0];
                $att1['password']=$info1[0]['password'][0];
                $att1['proxyserveraddress']=$info1[0]['proxyserveraddress'][0];
                $att1['proxyserverport']=$info1[0]['proxyserverport'][0];
                $att1['screensavermode']=$info1[0]['screensavermode'][0];
                $att1['screensaverparams']=$info1[0]['screensaverparams'][0];
                $att1['serialnumber']=$info1[0]['serialnumber'][0];
			} else {
                $phonetype=3;
                $move=$ipp;
                $att1['compressiontype']=$info1[0]['compressiontype'][0];
                $att1['model']=$info1[0]['model'][0];
                $att1['forcealerting']=$info1[0]['forcealerting'][0];
                $att1['forcespeech']=$info1[0]['forcespeech'][0];
                $att1['ipaddress']=$info1[0]['ipaddress'][0];
                $att1['noprogress']=$info1[0]['noprogress'][0];
                $att1['cn']=$info1[0]['cn'][0];
            }
            if(!$move) print "NOT moved<br/>";
            else {
            $to_dn="cn=".$att['cn'].",cn=$to,cn=Modules";
			print " > ".$to_dn." ";
            if(($phonetype==1 and $statusto!="Member") or $phonetype>1) ldap_add($ds,$to_dn,$att);
            else {
               unset($att['objectclass']);
               unset($att['cn']);
               unset($att1['objectclass']);
               unset($att1['cn']);
               ldap_modify($ds,$to_dn,$att);
            }
            $dn="cn=1,$to_dn";
            if(($phonetype==1 and $statusto!="Member") or $phonetype>1) ldap_add($ds,$dn,$att1); else ldap_modify($ds,$dn,$att1);
            if(($phonetype==1 and $statusfm!="Member") or $phonetype>1) ldap_delete($ds,$from_dn);
            $sr=ldap_read($ds,$to_dn,'objectclass=*');
            $info3=ldap_get_entries($ds,$sr);
            $to_phone=$info3[0]['guid'][0];
            $att2=array('cn','initialphone','currenthome');
            $sr=ldap_list($ds,'cn=Users',"(&(objectclass=User)(initialphone=$from_phone))",$att2);
            $info2=ldap_get_entries($ds,$sr);
            if ($info2['count']) {
                print " initial phone ".$info2[0]['cn'][0]." ";
                $att2=array();
                $att2['initialphone']=$to_phone;
                if ($ipp and $info2[0]['currenthome'][0]==$from_locn) $att2['currenthome']=$to_locn;
                $dn=$info2[0]['dn'];
                ldap_modify($ds,$dn,$att2);
            }
            print "<br/>";
            }
        }
    }
    $from=$to=-1;
}
// add temp modules
if (isset($_GET['add'])) {
   $cn="zczc temp 5330";
   $sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(cn=$cn))");
   $info=ldap_get_entries($ds,$sr);
   if ($info['count']==0) {
      $att=array('cn'=>$cn, 'description'=> 'temp PM5330 module - delete at will', 'moduletype'=>13, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.1', 'objectclass'=>'Module');
      ldap_add($ds,"cn=$cn,cn=Modules",$att);
   }
   $cn="zczc temp P308";
   $sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(cn=$cn))");
   $info=ldap_get_entries($ds,$sr);
   if ($info['count']==0) {
      $att=array('cn'=>$cn, 'description'=> 'temp P308 module - delete at will', 'moduletype'=>22, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.2', 'objectclass'=>'Module');
      ldap_add($ds,"cn=$cn,cn=Modules",$att);
   }
   
}
// delete temp modules
if (isset($_GET['delete'])) {
   @ldap_delete($ds,"cn=zczc temp 5330,cn=Modules");
   @ldap_delete($ds,"cn=zczc temp P308,cn=Modules");
}
// build array of nodes
$sr=@ldap_list($ds,"cn=Modules","objectclass=Module");
$info=ldap_get_entries($ds,$sr);
//		print "Module count = ".$info['count']."<br/>";
for($n=0; $n<$info['count'];$n++) {
    $n2 = count($modules['cn']);
    if ($info[$n]['moduletype'][0]==1) { $modules['type'][$n2]="4100"; $modules['potsp'][$n2]=0; $modules['ipp'][$n2]=1; }
    elseif ($info[$n]['moduletype'][0]==1 and substr($info[$n]['serialnumber'][0],0,8)!="00-07-d9") { $modules['type'][$n2]="XS"; $modules['potsp'][$n2]=0; $modules['ipp'][$n2]=1; }
    elseif ($info[$n]['moduletype'][0]==2) continue; //$modules['type'][$n2]="4200";
    elseif ($info[$n]['moduletype'][0]==3) { $modules['type'][$n2]="4315";  $modules['potsp'][$n2]=15; $modules['ipp'][$n2]=0; }
    elseif ($info[$n]['moduletype'][0]==4) { $modules['type'][$n2]="4330"; $modules['potsp'][$n2]=30; $modules['ipp'][$n2]=0; }
    elseif ($info[$n]['moduletype'][0]==7) continue; //$modules['type'][$n2]="VoIP";
    elseif ($info[$n]['moduletype'][0]==8) continue; //$modules['type'][$n2]="4400";
    elseif ($info[$n]['moduletype'][0]==10) { $modules['type'][$n2]="4140"; $modules['potsp'][$n2]=8; $modules['ipp'][$n2]=1; }
	elseif ($info[$n]['moduletype'][0]==11) { $modules['type'][$n2]="5100"; $modules['potsp'][$n2]=16;$modules['ipp'][$n2]=1; }
    elseif ($info[$n]['moduletype'][0]==12) { $modules['type'][$n2]="5108"; $modules['potsp'][$n2]=4; $modules['ipp'][$n2]=1; }
    elseif ($info[$n]['moduletype'][0]==13) { $modules['type'][$n2]="5330"; $modules['potsp'][$n2]=30; $modules['ipp'][$n2]=0; }
    elseif ($info[$n]['moduletype'][0]==14) { $modules['type'][$n2]="5315"; $modules['potsp'][$n2]=15;$modules['ipp'][$n2]=0; }
	elseif ($info[$n]['moduletype'][0]==22) { $modules['type'][$n2]="P308"; $modules['potsp'][$n2]=8;$modules['ipp'][$n2]=0; }
// updated
    elseif ($info[$n]['moduletype'][0]==17) { $modules['type'][$n2]="SoftPBX-Linux"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=1; }
	elseif ($info[$n]['moduletype'][0]==18) { $modules['type'][$n2]="SoftPBX-MAC"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=1; }
	elseif ($info[$n]['moduletype'][0]==19) { $modules['type'][$n2]="NSG"; $modules['potsp'][$n2]=4;$modules['ipp'][$n2]=1; }
	elseif ($info[$n]['moduletype'][0]==20) { $modules['type'][$n2]="Vision"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=0; }
// updated
    else { $modules['type'][$n2] = $info[$n]['moduletype'][0]; $modules['potsp'][$n2]=0; $modules['ipp'][$n2]=0; }
    $modules['cn'][$n2] = $info[$n]['cn'][0];
    $modules['guid'][$n2] = $info[$n]['guid'][0];
    $modules['version'][$n2] = $info[$n]['productversion'][0];
    if ($info[$n]['modulestatus'][0]==0) $modules['status'][$n2]="Member";
    elseif ($info[$n]['modulestatus'][0]==1) $modules['status'][$n2]="Available";
    elseif ($info[$n]['modulestatus'][0]==2) $modules['status'][$n2]="Non-Member";
    else $modules['status'][$n2] = $info[$n]['modulestatus'][0];
	$modules['ipaddress'][$n2] = $info[$n]['ipaddress'][0];
    $days=round((time()-$info[$n]['lastseen'][0])/(24*60*60))." days ago ";
    $modules['lastseen'][$n2] = $days;
    $sr2=@ldap_list($ds,$info[$n]['dn'],"(&(objectclass=Phone)(typeofphone=1))");
    $info2=ldap_get_entries($ds,$sr2);
    $modules['pots'][$n2]=$info2['count'];
    $sr2=@ldap_list($ds,$info[$n]['dn'],"(&(objectclass=Phone)(!(typeofphone=1)))");
    $info2=ldap_get_entries($ds,$sr2);
    $modules['ip'][$n2]=$info2['count'];
}


print "<p><b>WARNING</b> : Backup your config before using this tool - you are making very significant changes to the configuration using this feature.<br>
<p>This page is primarily for moving users between different modules, perhaps because a 4315 is being replaced by a 5330<br><br>
When users are moved from one module to another the users initial phone is changed to the module they have been moved to. If the module they are being moved from matches their Current Home this will also be changed to be the module they have been moved to.<br/>
When Pots ports are moved onto a \"Member\" of the system the destination always starts with port01.<br/><br/>
To use this feature select the tick box in the 'From' column which applies to the module you wish to move users from, then select the tick box in the 'To' column next to the module you wish to move users to.<br/>
Once you have selected the from and to options a box appears inviting you to 'move phones' - <b>DOUBLE CHECK YOUR SELECTIONS before clicking this box</b>.<br/><br/>
<b>Call Server Modules in System</b> :</p>";

print "<table border=1 id='tbl'>";
print "<thead><th>Item</th><th>IP Address</th><th>Module Name</th><th>Module Type</th><th>Status</th><th>No POTS Users</th><th>No IP Users</th><th>Move From</th><th>Move To</th></thead>";
foreach ($modules['ipaddress'] as $key => $value) {
	if ($modules['type'][$key]==="Vision") continue;
    if($key==$from) $checked_from = "checked"; else $checked_from = "";
    if($key==$to) $checked_to = "checked"; else $checked_to = "";
    print "<tr><td>".($key+1)."</td><td>".$modules['ipaddress'][$key]."</td><td>".$modules['cn'][$key]."</td>
        <td>".$modules['type'][$key]."</td><td>".$modules['status'][$key]."</td><td>".$modules['pots'][$key]." pots</td>
        <td>".$modules['ip'][$key]." ip</td>
        <td><form name=form method=post action=".$script.">
        <input type='hidden' name='to' value='".$to."'/>
        <input type='hidden' name='from' value='".$key."'/>From:
        <input name='checkbox' onClick=submit() type='checkbox' title='move phones from here' ".$checked_from." />
        </form></td>
        <td><form name=form method=post action=".$script.">
        <input type='hidden' name='from' value='".$from."'/>
        <input type='hidden' name='to' value='".$key."'/>To:
        <input name='checkbox' onClick=submit() type='checkbox' title='move phones to here' ".$checked_to." />
        </form></td>
        </tr>";
}
print "</table>";
if ($from!=$to and $from!=-1 and $to!=-1) {
print "<form name=form method=post action=".$script.">
        <input type='hidden' name='from' value='".$modules['cn'][$from]."'/>
        <input type='hidden' name='statusfm' value='".$modules['status'][$from]."'/>
        <input type='hidden' name='statusto' value='".$modules['status'][$to]."'/>
        <input type='hidden' name='to' value='".$modules['cn'][$to]."'/>
        <input type='hidden' name='ipp' value='".$modules['ipp'][$to]."'/>
        <input type='hidden' name='potsp' value='".$modules['potsp'][$to]."'/>
        <input name='submit' onClick=submit() type='submit' title='click to move phones' value='Move Phones' />
	    </form>";
}
if(isset($_GET['fix'])) {
   foreach ($modules['potsp'] as $key => $value) {
      if ($value==0) continue;
      if ($modules['status'][$key]!="Member") continue;
      $cn=$modules['cn'][$key];
      print "$cn ";
      $ports=array();
      for ($n=1;$n<=$value;$n++) {
         $ports[$n]=sprintf("port%02d",$n);
      }
      $dn="guid=".$modules['guid'][$key];
      $sr=ldap_list($ds,$dn,"(&(objectclass=Phone)(typeofphone=1))");
      $info=ldap_get_entries($ds,$sr);
      for ($n2=0;$n2<$info['count'];$n2++) {
         if ($port=array_search($info[$n2]['cn'][0],$ports)) {
         unset($ports[$port]);
         }
         else {
            print " -[".$info[$n2]['cn'][0]."]is not a POTS Phone, DELETED- ";
            $dn = "guid=".$info[$n2]['guid'][0];
            ldap_delete($ds,$dn);
         }
      }
      if (count($ports)) {
         foreach($ports as $k => $v) {
            print " +$v+ ";
            $att=array('cn'=>$v, 'description'=>'POTS Phone', 'typeofphone'=>1, 'objectclass'=>'Phone');
            ldap_add($ds,"cn=$v,cn=$cn,cn=Modules",$att);
            $att=array('cn'=>1, 'objectclass'=>'POTSPhone');
            ldap_add($ds,"cn=1,cn=$v,cn=$cn,cn=Modules",$att);
         }
      }
      print " Done.<br/>";
   }
}
print "<p>".date(" H:i:s l, jS F Y",time())."</p>";
?>
</div>
</body>
</html>
